 function [A B]=AJDcf_analytic(kappa,theta,sigma,mu,l,q,T)
%   AJDcf_analytic returns A and B in E[exp(\int_0^T [qX_s]ds)]=exp(A+BX_0)
%   X is a basic affine process, dX=kappa(theta-X)dt+sigma\sqrt(X)dW+dJ,
%   where
%   the jump sizes of J are independent and expontially distributed with
%   mean mu and whose jump sizes are those of an independent Poisson
%   process with mean jump arrival rate l
%   The result is in Duffie and Garleanu(2001) or
%   Duffie and Singleton(2003) Appendix A5
%   written by Peter Feldhtter, 2007
m=kappa*theta;
n=-kappa;
p=sigma^2;
c1=(-n+sqrt(n^2-2*p*q))./(2*q);
d1=(n+sqrt(n^2-2*p*q))./(2*q);
b1=-(d1.*(n+2*q.*c1)-(n*c1+p))./(c1+d1);
a2=d1./c1;
c2=1.-mu./c1;
d2=(d1+mu)./c1;
B=(1-exp(b1*T))./(c1+d1.*exp(b1*T));
A=-m*(c1+d1)./(b1.*c1.*d1).*log((c1+d1.*exp(b1*T))./(c1+d1))+m*T./c1+l*(a2.*c2-d2)./(b1.*c2.*d2).*log((c2+d2.*exp(b1*T))./(c2+d2))+(l./c2-l)*T;
notdef = find(isnan(A)); A(notdef)=0; B(notdef)=0;