%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Model with index-CDS and index-tranche basis %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% Prepare data
cdx_mor = rmfield(cdx_mor, 'liq_prem_cds');
cdx_mor = rmfield(cdx_mor, 'liq_prem_tranches');
cdx_mor.basis_cds = 0;
cdx_mor.basis_tr = 0;

cdx_mor = fit_basis_cds(cdx_mor, discounts_IMM, datenum('12/05/2005'), datenum('12/05/2005'), 2^18, [1 0 0 1], [1 0 0], 121, 0, ...
                        'mu*L', 'thet*k', CDX_NA_IG);
cdx_mor = fit_basis_tranches(cdx_mor, discounts_IMM, datenum('12/05/2005'), datenum('12/05/2005'), 2^18, [1 0 0 1], [1 0 0], 121, 0, ...
                             'mu*L', 'thet*k', CDX_NA_IG);
tic; 
[trash, test] = wrapper_tranche_mispricing(get_x0(cdx_mor, cdx_mor.dates{1}, 'mu*L', 'thet*k'), cdx_mor, discounts_IMM, datenum('12/05/2005'), ...
                                           datenum('12/05/2005'), 2^18, [1 0 0 1], [1 0 0], 121, 0, 2, 'mu*L', 'thet*k', CDX_NA_IG);                                      
toc; 

%%% Deterministic LGD
tic;
[cdx_mor, trash, x0_diff] = iterative_fitting2(cdx_mor, discounts_IMM, datenum('12/05/2005'), datenum('12/05/2005'), [1 0 0 1], [1 0 0], 2^18, ...
                                              10, 121, 0, ones(10,1), 'mu*L', 'thet*k', CDX_NA_IG);
toc;
save_fitted_model(cdx_mor, 'Mort', datenum('12/05/2005'), datenum('12/05/2005'))
cdx_mor = load_fitted_model(cdx_mor, 'Mort10');


%%% Fit to BBG data
cdx_mor_bbg = cdx_mor;
cdx_mor_bbg.tranche_market_price_mid{1} = [500 117.5 32.9 15.8 7];
cdx_mor_bbg.tranche_market_upfront_mid{1}(1) = 0.411;
tic;
[cdx_mor_bbg, trash, x0_diff] = iterative_fitting2(cdx_mor_bbg, discounts_IMM, datenum('12/05/2005'), datenum('12/05/2005'), ...
                                                   [1 0 0 1], [1 0 0], 2^18, 25, 121, 0, ones(10,1), 'mu*L', 'thet*k', CDX_NA_IG);
toc;

%%% Deterministic LGD - all horizons
cdx_mor10 = rmfield(cdx_mor10, 'liq_prem_cds');
cdx_mor10 = rmfield(cdx_mor10, 'liq_prem_tranches');
cdx_mor10.basis_cds = 0;
cdx_mor10.basis_tr = 0;
cdx_mor10 = fit_basis_cds(cdx_mor10, discounts_IMM, datenum('12/05/2005'), datenum('12/05/2005'), 2^18, [1 1 1 0], [1 1 1], 121, 0, ...
                        'mu*L', 'thet*k', CDX_NA_IG);
cdx_mor10 = fit_basis_tranches(cdx_mor10, discounts_IMM, datenum('12/05/2005'), datenum('12/05/2005'), 2^18, [1 1 1 0], [1 1 1], 121, 0, ...
                             'mu*L', 'thet*k', CDX_NA_IG);
[trash, test] = wrapper_tranche_mispricing(get_x0(cdx_mor10), cdx_mor10, discounts_IMM, datenum('12/05/2005'), datenum('12/05/2005'), ...
                                           2^18, [1 1 1 0], [1 1 1], 121, 0, 2, 'mu*L', 'thet*k', CDX_NA_IG); 
                                       
tic;
cdx_mor10 = iterative_fitting2(cdx_mor10, discounts_IMM, datenum('12/05/2005'), datenum('12/05/2005'), [1 1 1 1], [1 1 1], 2^18, 25, 121, 0, ones(10,1), 'mu*L', 'thet*k', CDX_NA_IG);
toc;
save_fitted_model(cdx_mor10, 'Mort10', datenum('12/05/2005'), datenum('12/05/2005'))
cdx_mor10 = load_fitted_model(cdx_mor10, 'Mort10');


% Stochastic (but uncorrelated) LGD
cdx_mor_lgd1 = cdx_mor;
[trash, test] = wrapper_tranche_mispricing(get_x0(cdx_mor_lgd1), cdx_mor_lgd1, discounts_IMM, datenum('12/05/2005'), datenum('12/05/2005'), ...
                                           2^18, [1 0 0 1], [1 0 0], 121, 1, 2, 'mu*L', 'thet*k', CDX_NA_IG);
                                       
cdx_mor_lgd1 = fit_basis_cds(cdx_mor_lgd1, discounts_IMM, datenum('12/05/2005'), datenum('12/05/2005'), 2^18, [1 0 0 1], [1 0 0], 121, 1, ...
                        'mu*L', 'thet*k', CDX_NA_IG);
cdx_mor_lgd1 = fit_basis_tranches(cdx_mor_lgd1, discounts_IMM, datenum('12/05/2005'), datenum('12/05/2005'), 2^18, [1 0 0 1], [1 0 0], 121, 1, ...
                             'mu*L', 'thet*k', CDX_NA_IG);
                         
cdx_mor_lgd1 = iterative_fitting2(cdx_mor_lgd1, discounts_IMM, datenum('12/05/2005'), datenum('12/05/2005'), [1 0 0 1], [1 0 0], ...
                                 2^18, 10, 121, 1, ones(10,1), 'mu*L', 'thet*k', CDX_NA_IG);
save_fitted_model(cdx_mor_lgd1, 'Mort LGD1', datenum('12/05/2005'), datenum('12/05/2005'))
cdx_mor_lgd1 = load_fitted_model(cdx_mor_lgd1, 'Mort LGD1');

% Stochastic (but uncorrelated) LGD - all horizons
cdx_mor10_lgd1 = cdx_mor10;
[trash, test] = wrapper_tranche_mispricing(get_x0(cdx_mor10_lgd1), cdx_mor10_lgd1, discounts_IMM, datenum('12/05/2005'), datenum('12/05/2005'), ...
                                           2^18, [1 1 1 0], [1 1 1], 121, 1, 2, 'mu*L', 'thet*k', CDX_NA_IG);                                     
tic;
cdx_mor10_lgd1 = iterative_fitting2(cdx_mor10_lgd1, discounts_IMM, datenum('12/05/2005'), datenum('12/05/2005'), ...
                                   [1 1 1 0], [1 1 1], 2^18, 10, 121, 1, ones(10,1), 'mu*L', 'thet*k', CDX_NA_IG);
toc;


% Stochastic and serially correlated LGD
cdx_mor_lgd3 = cdx_mor;
[trash, test] = wrapper_tranche_mispricing(get_x0(cdx_mor_lgd3), cdx_mor_lgd3, discounts_IMM, datenum('12/05/2005'), datenum('12/05/2005'), ...
                                           2^18, [1 0 0 1], [1 0 0], 121, 3, 2, 'mu*L', 'thet*k', CDX_NA_IG);

cdx_mor_lgd3 = iterative_fitting2(cdx_mor_lgd3, discounts_IMM, datenum('12/05/2005'), datenum('12/05/2005'), [1 0 0 1], [1 0 0], ...
                                  2^18, 5, 121, 3, ones(10,1), 'mu*L', 'thet*k', CDX_NA_IG);
[rho_n, cdx_mor_lgd3] = optimize_rho_n(cdx_mor_lgd3, discounts_IMM, datenum('12/05/2005'), datenum('12/05/2005'), ...
                                       2^18, [1 0 0 0], [1 0 0], 121, 0.05, 'mu*L', 'thet*k', CDX_NA_IG);
[rho_n, cdx_mor_lgd3] = optimize_rho_n(cdx_mor_lgd3, discounts_IMM, datenum('12/05/2005'), datenum('12/05/2005'), ...
                                       2^18, [1 0 0 0], [1 0 0], 121, 0.01, 'mu*L', 'thet*k', CDX_NA_IG);
                                   
save_fitted_model(cdx_mor_lgd3, 'Mort LGD3', datenum('12/05/2005'), datenum('12/05/2005'))
cdx_mor_lgd3 = load_fitted_model(cdx_mor_lgd3, 'Mort LGD3');

% Stochastic and serially correlated LGD - all horizons
cdx_mor10_lgd3 = cdx_mor10;
[trash, test] = wrapper_tranche_mispricing(get_x0(cdx_mor10_lgd3), cdx_mor10_lgd3, discounts_IMM, datenum('12/05/2005'), datenum('12/05/2005'), ...
                                           2^18, [1 1 1 0], [1 1 1], 121, 3, 2, 'mu*L', 'thet*k', CDX_NA_IG);

tic;
cdx_mor10_lgd3 = iterative_fitting2(cdx_mor10_lgd3, discounts_IMM, datenum('12/05/2005'), datenum('12/05/2005'), [1 1 1 0], [1 1 1], 2^18, 2, 121, 3, ones(10,1), 'mu*L', 'thet*k', CDX_NA_IG);
toc;

[rho_n, cdx_mor10_lgd3] = optimize_rho_n(cdx_mor10_lgd3, discounts_IMM, datenum('12/05/2005'), datenum('12/05/2005'), ...
                                         2^18, [1 1 1 0], [1 1 1], 121, 0.05, 'mu*L', 'thet*k', CDX_NA_IG);


